@@ -4,12 +4,15 @@
 
 echo "appli_name=${appli_name}"
 
-list=$(find /usr -name ${appli_name} 2>/dev/null)
+list=$(find /usr/share -name ${appli_name} 2>/dev/null)
 
 for folder in $list
 do
-   echo "to delete : '$folder'"
-   rm -r $folder
+   if [ $folder != '/usr/share/OSCAR' ]
+   then
+      echo "to delete : '$folder'"
+      rm -r $folder
+   fi
 done
 
 # end common script shell
