@@ -7,6 +7,9 @@
  * License. See the file COPYING in the main directory of the source code
  * for more details. */
 
+#define TEST_MACROS_ENABLEDoff
+#include "test_macros.h"
+
 #include <math.h>
 #include <QLabel>
 #include <QDateTime>
@@ -104,13 +107,11 @@ void gSummaryChart::SetDay(Day *unused_day)
     m_maxy = 20;
 
     m_empty = false;
+    m_emptyPrev = true;
 
 }
 
 
-//QMap<QDate, int> gSummaryChart::dayindex;
-//QList<Day *> gSummaryChart::daylist;
-
 int gSummaryChart::addCalc(ChannelID code, SummaryType type, QColor color)
 {
     calcitems.append(SummaryCalcItem(code, type, color));
@@ -565,7 +566,8 @@ void gSummaryChart::paint(QPainter &painter, gGraph &graph, const QRegion &regio
 
         totaldays++;
 
-        if (!day) {//  || !day->hasMachine(m_machtype)) {
+        if (!day)
+        {
            // lasty1 = rect.bottom();
             lastx1 += barw;
             it++;
@@ -675,9 +677,13 @@ void gSummaryChart::paint(QPainter &painter, gGraph &graph, const QRegion &regio
 
     // This could be turning off graphs prematurely..
     if (cache.size() == 0) {
-
         m_empty = true;
+        m_emptyPrev = true;
         graph.graphView()->updateScale();
+        emit summaryChartEmpty(this,m_minx,m_maxx,true);
+    } else if (m_emptyPrev) {
+        m_emptyPrev = false;
+        emit summaryChartEmpty(this,m_minx,m_maxx,false);
     }
 
 }
@@ -1019,8 +1025,8 @@ void gSessionTimesChart::paint(QPainter &painter, gGraph &graph, const QRegion &
 
         totaldays++;
 
-
-        if (!day) { // || !day->hasMachine(m_machtype)) {
+        if (!day)
+        {
            // lasty1 = rect.bottom();
             lastx1 += barw;
             nousedays++;
@@ -1091,6 +1097,7 @@ void gSessionTimesChart::paint(QPainter &painter, gGraph &graph, const QRegion &
     afterDraw(painter, graph, rect);
 }
 
+
 ////////////////////////////////////////////////////////////////////////////
 /// Total Time in Apnea Chart Stuff
 ////////////////////////////////////////////////////////////////////////////
