@@ -539,7 +539,7 @@ void PRS1DataChunk::ParseHumidifierSetting50Series(int humid, bool add_setting)
 
     // Check for truly unexpected values:
     if (humidlevel > 5) UNEXPECTED_VALUE(humidlevel, "<= 5");
-    //if (!humidifier_present) CHECK_VALUES(humidlevel, 0, 1);  // Some machines appear to encode the humidlevel setting even when the humidifier is not present.
+    //if (!humidifier_present) CHECK_VALUES(humidlevel, 0, 1);  // Some devices appear to encode the humidlevel setting even when the humidifier is not present.
 }
 
 
@@ -713,12 +713,11 @@ void PRS1DataChunk::ParseHumidifierSetting60Series(unsigned char humid1, unsigne
     } else if (this->familyVersion == 2) {
         // F5V2
         if (tubepresent) {
-            CHECK_VALUES(tubetemp, 0, 3);
+            // all tube temperatures seen
             if (tubetemp) {
-                CHECK_VALUE(tubehumidlevel, 1);
+                CHECK_VALUES(tubehumidlevel, 1, 3);
             }
         }
-        CHECK_VALUE(humidsystemone, false);
         CHECK_VALUE(humidclassic, false);
     }
 }
@@ -916,6 +915,7 @@ void PRS1DataChunk::ParseTubingTypeV3(unsigned char type)
     case 1: diam = 15; break;
     case 2: diam = 15; break;  // 15HT, though the reports only say "15" for DreamStation models
     case 3: diam = 12; break;  // seen on DreamStation Go models
+    case 4: diam = 12; break;  // HT12, seen on DreamStation 2 models
     default:
         UNEXPECTED_VALUE(type, "known tubing type");
         return;
@@ -1102,7 +1102,7 @@ bool PRS1DataChunk::ReadNormalHeaderV3(RawDataDevice & f)
     unsigned char * header;
     QByteArray headerB2;
 
-    // This is a new machine, byte 15 is header data block length
+    // This is a new device, byte 15 is header data block length
     // followed by variable, data byte pairs
     do {
         QByteArray extra = f.read(1);
@@ -1395,9 +1395,9 @@ static crc32_t CRC32(const unsigned char *data, size_t data_len, crc32_t crc)
 }
 
 
-// Strangely, the PRS1 CRC32 appears to consider every byte a 32-bit wchar_t.
-// Nothing like trying a bunch of encodings and CRC32 variants on PROP.TXT files
-// until you find a winner.
+// The PRS1 CRC32 considers every byte a 32-bit wchar_t, presumably due to
+// use of the STM32 CRC calculation unit, in which "CRC computation is done
+// on the whole 32-bit data word, and not byte per byte".
 
 static crc32_t CRC32wchar(const unsigned char *data, size_t data_len, crc32_t crc)
 {
