@@ -37,7 +37,7 @@ static QSet<QString> s_unexpectedMessages;
 bool
 ViatomLoader::Detect(const QString & path)
 {
-    // This is only used for CPAP machines, when detecting CPAP cards.
+    // This is only used for CPAP devices, when detecting CPAP cards.
     qDebug() << "ViatomLoader::Detect(" << path << ")";
     return false;
 }
@@ -74,7 +74,7 @@ ViatomLoader::Open(const QStringList & paths)
     }
 
     Machine* mach = m_mach;
-    if (imported && mach == nullptr) qWarning() << "No machine record created?";
+    if (imported && mach == nullptr) qWarning() << "No device record created?";
     if (mach) {
         qDebug() << "Imported" << imported << "sessions";
         mach->Save();
@@ -82,7 +82,7 @@ ViatomLoader::Open(const QStringList & paths)
         p_profile->StoreMachines();
     }
     if (mach && s_unexpectedMessages.count() > 0 && p_profile->session->warnOnUnexpectedData()) {
-        // Compare this to the list of messages previously seen for this machine
+        // Compare this to the list of messages previously seen for this device
         // and only alert if there are new ones.
         QSet<QString> newMessages = s_unexpectedMessages - mach->previouslySeenUnexpectedData();
         if (newMessages.count() > 0) {
@@ -418,19 +418,23 @@ QList<ViatomFile::Record> ViatomFile::ReadData()
         QList<ViatomFile::Record> dedup;
         bool all_are_duplicated = true;
 
-        CHECK_VALUE(records.size() % 2, 0);
-        for (int i = 0; i < records.size(); i += 2) {
-            auto & a = records.at(i);
-            auto & b = records.at(i+1);
-            if (a.spo2 != b.spo2
-                || a.hr != b.hr
-                || a.oximetry_invalid != b.oximetry_invalid
-                || a.motion != b.motion
-                || a.vibration != b.vibration) {
-                all_are_duplicated = false;
-                break;
+        if ((records.size() % 2) != 0) {
+            // An odd number of samples inherently can't be all duplicates.
+            all_are_duplicated = false;
+        } else {
+            for (int i = 0; i < records.size(); i += 2) {
+                auto & a = records.at(i);
+                auto & b = records.at(i+1);
+                if (a.spo2 != b.spo2
+                    || a.hr != b.hr
+                    || a.oximetry_invalid != b.oximetry_invalid
+                    || a.motion != b.motion
+                    || a.vibration != b.vibration) {
+                    all_are_duplicated = false;
+                    break;
+                }
+                dedup.append(a);
             }
-            dedup.append(a);
         }
         if (m_sig == 5) {
             // Confirm that CheckMe O2 Max is a true 2s sample rate.
